#!/usr/bin/python
# -*- coding: utf-8 -*-

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
# 
# Author: Tomas "Tojaj" Mlcoch (xtojaj gmail dot com)
# Web: http://tojaj.com
#
# Copyright 2010 Tomas Mlcoch


import ConfigParser
from core.target import PingTarget


CONFIG_FILE = 'config.ini'

class Settings(object):
    """Settings object for save settings on exit and load it on start."""

    def __init__(self):
        self.ip_addresses = []
        self.model = None
        self.lock = None
        self.logging = True

    def parse_arg(self, argv):
        """Parses command line agruments."""
        pass

    def save(self):
        """Saves all ping targets from model."""
        try:
            conffile = open(CONFIG_FILE, 'wb')
        except (IOError):
            return False

        self.lock.acquire()
        ips = ' '.join(self.model.get_names())
        self.lock.release()

        config = ConfigParser.RawConfigParser()
        config.add_section('Main')
        config.set('Main', 'Addresses', ips)
        config.set('Main', 'Logging', self.logging)
        config.write(conffile)
        return True

    def load(self):
        """Loads ping targets into model."""
        config = ConfigParser.RawConfigParser()
        config.read(CONFIG_FILE)
        try:
            self.ip_addresses = config.get('Main', 'Addresses').split()
            self.logging = config.getboolean('Main', 'Logging')
        except (ConfigParser.NoSectionError, ConfigParser.NoOptionError):   
            return

    def fill_model(self, model, lock):
        """Sets up data model and lock for accessing data in model."""
        self.model = model
        self.lock = lock
        for addr in self.ip_addresses:
            dst = PingTarget(addr)
            if dst.ready:
                self.lock.acquire()
                self.model.addItem(dst)
                self.lock.release()
