#!/usr/bin/python
# -*- coding: utf-8 -*-

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
# 
# Author: Tomas "Tojaj" Mlcoch (xtojaj gmail dot com)
# Web: http://tojaj.com
#
# Copyright 2010 Tomas Mlcoch


import target
from PyQt4.QtCore import * 
from PyQt4.QtGui import * 

IP_EXIST = """This IP address already exist in list!

Note: 
Some domains may share same IP address.
IP address of: 
{0} 
is same as: 
{1}."""

BAD_ADDR = "Bad address: \"{0}\"."


class MainWindow(QWidget): 
    def __init__(self, model, lock, *args): 
        QWidget.__init__(self, *args) 
        self.lock = lock
        self.model = model
        self.setMinimumSize(580, 180)
        self.center()
        self.setWindowIcon(QIcon('data/pyping.png'))

        # create table
        self.table = self.createTable(self.model) 

        # create head part
        head = self._headPart()

        # layout
        layout = QVBoxLayout()
        layout.addWidget(head)
        layout.addWidget(self.table) 
        self.setLayout(layout) 

    def center(self):
        """Centering window on the screen."""
        scr = QDesktopWidget().screenGeometry()
        size =  self.geometry()
        self.move((scr.width()-size.width())/2, (scr.height()-size.height())/2)

    def _headPart(self):
        """Creates top part of window (lineedit and two buttons)."""
        horizontal = QGroupBox('PyPinger');
        linelayout = QHBoxLayout()

        self.lineedit = QLineEdit()
        addbutton = QPushButton('Add IP address')
        delbutton = QPushButton('Del. current IP address')

        self.connect(self.lineedit, SIGNAL('returnPressed()'), self.addIpSlot)
        self.connect(addbutton, SIGNAL('clicked()'), self.addIpSlot)
        self.connect(delbutton, SIGNAL('clicked()'), self.delIpSlot)

        linelayout.addWidget(self.lineedit)
        linelayout.addWidget(addbutton)
        linelayout.addWidget(delbutton)

        horizontal.setLayout(linelayout)
        return horizontal

    def createTable(self, model):
        """Creates and sets up table view."""

        table = QTableView()
        table.setModel(model)
        table.setColumnHidden(1, True)
        table.setShowGrid(False)
        table.resizeColumnsToContents()
        table.setSelectionBehavior(QAbstractItemView.SelectRows)

        # vertical header
        vheader = table.verticalHeader()
        vheader.setResizeMode(QHeaderView.ResizeToContents)
        vheader.setVisible(False)

        # set horizontal header properties
        hheader = table.horizontalHeader()
        hheader.setResizeMode(QHeaderView.Interactive) # .ResizeToContents
        hheader.setStretchLastSection(True)
  
        return table

    def addIpSlot(self): 
        """Adds new item into model."""
        dst_txt = self.lineedit.text()
        if not dst_txt:
            return

        dst = target.PingTarget(str(dst_txt))
        if not dst.ready:
            QMessageBox.warning(None, "Warning", BAD_ADDR.format(dst_txt), 'Ok')   
            return

        self.lock.acquire()
        ret = self.model.addItem(dst)
        self.lock.release()

        if ret:
            self.lineedit.setText('')
        else:
            alias = self.model[dst.ip] 
            if alias:
                alias = alias.name
            QMessageBox.warning(None, "Warning", 
                IP_EXIST.format(dst_txt, alias), 'Ok')

    def delIpSlot(self): 
        """Removes item(s) from model."""
        rows = sorted(self.table.selectionModel().selectedRows(0), reverse=True)
        self.lock.acquire()
        for row in rows:           
            self.model.delItem(row.row())
        self.lock.release()
